==> opencart_v1.5.0.zip: opencart_v1.5.0/upload/admin/language/english/sale/customer.php <==
<?php
// Heading
$_['heading_title']         = 'Customer';

// Text
$_['text_login']            = 'Login';
$_['text_success']          = 'Success: You have modified customers!';
$_['text_approved']         = 'You have approved %s accounts!';
$_['text_wait']             = 'Please Wait!';
$_['text_balance']          = 'Balance:';

// Column
$_['column_name']           = 'Customer Name';
$_['column_email']          = 'E-Mail';
$_['column_customer_group'] = 'Customer Group';
$_['column_status']         = 'Status'; 
$_['column_approved']       = 'Approved';
$_['column_date_added']     = 'Date Added';
$_['column_description']    = 'Description';
$_['column_amount']         = 'Amount';
$_['column_points']         = 'Points';
$_['column_ip']             = 'IP';
$_['column_total']          = 'Total Accounts';
$_['column_action']         = 'Action';

// Entry
$_['entry_firstname']       = 'First Name:';
$_['entry_lastname']        = 'Last Name:';
$_['entry_email']           = 'E-Mail:';
$_['entry_telephone']       = 'Telephone:';
$_['entry_fax']             = 'Fax:';
$_['entry_newsletter']      = 'Newsletter:';
$_['entry_customer_group']  = 'Customer Group:';
$_['entry_status']          = 'Status:';
$_['entry_password']        = 'Password:';
$_['entry_confirm']         = 'Confirm:';
$_['entry_company']         = 'Company:';
$_['entry_address_1']       = 'Address 1:';
$_['entry_address_2']       = 'Address 2:';
$_['entry_city']            = 'City:';
$_['entry_postcode']        = 'Postcode:';
$_['entry_country']         = 'Country:';
$_['entry_zone']            = 'Region / State:';
$_['entry_default']         = 'Default Address:';
$_['entry_amount']          = 'Amount:';
$_['entry_points']          = 'Points:';
$_['entry_description']     = 'Description:';

// Error
$_['error_warning']         = 'Warning: Please check the form carefully for errors!';
$_['error_permission']      = 'Warning: You do not have permission to modify customers!';
$_['error_firstname']       = 'First Name must be between 1 and 32 characters!';
$_['error_lastname']        = 'Last Name must be between 1 and 32 characters!';
$_['error_email']           = 'E-Mail Address does not appear to be valid!';
$_['error_telephone']       = 'Telephone must be between 3 and 32 characters!';
$_['error_password']        = 'Password must be between 4 and 20 characters!';
$_['error_confirm']         = 'Password and password confirmation do not match!';
$_['error_address_1']       = 'Address 1 must be between 3 and 128 characters!';
$_['error_city']            = 'City must be between 2 and 128 characters!';
$_['error_postcode']        = 'Postcode must be between 2 and 10 characters for this country!';
$_['error_country']         = 'Please select a country!';
$_['error_zone']            = 'Please select a region / state!';
?>

==> opencart_v1.5.3.zip: opencart_v1.5.3/upload/admin/language/english/sale/customer.php <==
<?php
// Heading
$_['heading_title']         = 'Customer';

// Text
$_['text_success']          = 'Success: You have modified customers!';
$_['text_default']          = 'Default';
$_['text_approved']         = 'You have approved %s accounts!';
$_['text_wait']             = 'Please Wait!';
$_['text_balance']          = 'Balance:';
$_['text_add_blacklist']    = 'Add Blacklist';
$_['text_remove_blacklist'] = 'Remove Blacklist';

// Column
$_['column_name']           = 'Customer Name';
$_['column_email']          = 'E-Mail';
$_['column_customer_group'] = 'Customer Group';
$_['column_status']         = 'Status'; 
$_['column_login']          = 'Login into Store';
$_['column_approved']       = 'Approved';
$_['column_date_added']     = 'Date Added';
$_['column_description']    = 'Description';
$_['column_amount']         = 'Amount';
$_['column_points']         = 'Points';
$_['column_ip']             = 'IP';
$_['column_total']          = 'Total Accounts';
$_['column_action']         = 'Action';

// Entry
$_['entry_firstname']       = 'First Name:';
$_['entry_lastname']        = 'Last Name:';
$_['entry_email']           = 'E-Mail:';
$_['entry_telephone']       = 'Telephone:';
$_['entry_fax']             = 'Fax:';
$_['entry_newsletter']      = 'Newsletter:';
$_['entry_customer_group']  = 'Customer Group:';
$_['entry_status']          = 'Status:';
$_['entry_password']        = 'Password:';
$_['entry_confirm']         = 'Confirm:';
$_['entry_company']         = 'Company:';
$_['entry_company_id']      = 'Company ID:';
$_['entry_tax_id']          = 'Tax ID:';
$_['entry_address_1']       = 'Address 1:';
$_['entry_address_2']       = 'Address 2:';
$_['entry_city']            = 'City:';
$_['entry_postcode']        = 'Postcode:';
$_['entry_country']         = 'Country:';
$_['entry_zone']            = 'Region / State:';
$_['entry_default']         = 'Default Address:';
$_['entry_amount']          = 'Amount:';
$_['entry_points']          = 'Points:<br /><span class="help">Use minus to remove points</span>';
$_['entry_description']     = 'Description:';

// Error
$_['error_warning']         = 'Warning: Please check the form carefully for errors!';
$_['error_permission']      = 'Warning: You do not have permission to modify customers!';
$_['error_exists']          = 'Warning: E-Mail Address is already registered!';
$_['error_firstname']       = 'First Name must be between 1 and 32 characters!';
$_['error_lastname']        = 'Last Name must be between 1 and 32 characters!';
$_['error_email']           = 'E-Mail Address does not appear to be valid!';
$_['error_telephone']       = 'Telephone must be between 3 and 32 characters!';
$_['error_password']        = 'Password must be between 4 and 20 characters!';
$_['error_confirm']         = 'Password and password confirmation do not match!';
$_['error_company_id']      = 'Company ID required!';
$_['error_tax_id']          = 'Tax ID required!';
$_['error_vat']             = 'VAT number is invalid!';
$_['error_address_1']       = 'Address 1 must be between 3 and 128 characters!';
$_['error_city']            = 'City must be between 2 and 128 characters!';
$_['error_postcode']        = 'Postcode must be between 2 and 10 characters for this country!';
$_['error_country']         = 'Please select a country!';
$_['error_zone']            = 'Please select a region / state!';
?>
